.. include:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 2

   Overview <readme>

.. toctree::
   :caption: Advanced Usage
   :hidden:

   benchmark
   database
   docker

.. toctree::
   :caption: Resources
   :hidden:

   API Reference <api/orion>
   contributing
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
